﻿import com.robertpenner.geom.Vector;
import com.robertpenner.physics.PhysicsParticle;

/**
* The Force class provides an API for assigning physics forces to objects.
* 
* @author Robert Penner (AS 1.0)
* © 2002 Robert Penner
* http://www.robertpenner.com
* 
* @author Mark Walters (AS 2.0)
* © 2006 DigitalFlipbook
* http://www.digitalflipbook.com
* 
* @version	1.0
* 
* @since	ActionScript 2.0; Flash Player 6
*/
class com.robertpenner.physics.Force {
	
	/*
	* CLASS PROPERTIES
	*/
	private var $value:Vector;
	private var $life:Number;
	private var $parent:PhysicsParticle;
	private var $parentPos:Vector;
	
	
	/*
	* *********************************************************
	* CONSTRUCTOR
	* *********************************************************
	*
	*/
	
	/**
	* Creates an instance of the Force class.
	* 
	* @param	x			The initial x value of the force.
	* @param	y			The initial y value of the force.
	* @param	life		The lifespan of the force in frames; this defaults to infinity if the parameter is omitted.
	* 
	* @usage
	* <pre><code>
	* var f:Force = new Force(-8, 0);
	* </code></pre>
	*/
	function Force (x:Number, y:Number, life:Number) {
		this.$value = new Vector (x, y);
		this.life = life;
	}
	
	
	/*
	* *********************************************************
	* PRIVATE METHODS
	* *********************************************************
	* 
	*/
	
	private function update ():Void {
	}
	
	
	/*
	* *********************************************************
	* PUBLIC METHODS
	* *********************************************************
	* 
	*/
	
	/**
	* Causes the Force object to "live for one frame"; returns false if the force is dead, and true if alive.
	* 
	* @usage
	* <pre><code>
	* f.live();
	* </code></pre>
	*/
	public function live ():Boolean {
		if (this.$life-- <= 0) {
			return false;
		} else {
			this.update();
			return true;
		}
	}
	
	/**
	* Gets the value of a Force instance.
	* 
	* @usage
	* <pre><code>
	* trace (f.getValue());
	* </code></pre>
	*/
	public function getValue ():Vector {
		return this.value;
	}
	
	/**
	* Sets the value of a Force instance.
	* 
	* @param	x			The x position of the Force.
	* @param	y			The y position of the Force.
	* 
	* @usage
	* <pre><code>
	* var f:Force = new Force(-8, 0);
	* f.setValue(10, 10);
	* </code></pre>
	*/
	public function setValue (x:Number, y:Number):Void {
		this.$value.reset (x, y);
	}
	
	
	/*
	* *********************************************************
	* GETTERS/SETTERS
	* *********************************************************
	* 
	*/
	
	/**
	* The value property of the Force.
	* 
	* @usage
	* <pre><code>
	* trace (f.value);
	* </code></pre>
	*/
	public function get value ():Vector {
		return this.$value;
	}
	
	/**
	* The life property of the Force.
	* 
	* @usage
	* <pre><code>
	* trace (f.life);
	* </code></pre>
	*/
	public function get life ():Number {
		return this.$life;
	}
	public function set life (l:Number):Void {
		 this.$life = (l == undefined) ? Infinity : l;
	}
	
	/**
	* The parent property of the Force.
	* 
	* @usage
	* <pre><code>
	* trace (f.parent);
	* </code></pre>
	*/
	public function get parent ():PhysicsParticle {
		return this.$parent;
	}
	public function set parent (p:PhysicsParticle):Void {
		this.$parent = p;
		this.$parentPos = p.position;
	}
	
}
