﻿import com.robertpenner.geom.Vector;
import com.robertpenner.physics.Force;

/**
* The ElasticForce class implements elastic force according to Hooke's Law. 
* Extends the Force class.
* Designed to collaborate with the PhysicsParticle class.
* 
* @author Robert Penner (AS 1.0)
* © 2002 Robert Penner
* http://www.robertpenner.com
* 
* @author Mark Walters (AS 2.0)
* © 2006 DigitalFlipbook
* http://www.digitalflipbook.com
* 
* @version	1.0
* 
* @since	ActionScript 2.0; Flash Player 6
*/
class com.robertpenner.physics.forces.ElasticForce extends Force {
	
	/*
	* CLASS PROPERTIES
	*/
	private var $anchor:Vector;
	private var $tautness:Number = 0;
	
	
	/*
	* *********************************************************
	* CONSTRUCTOR
	* *********************************************************
	*
	*/
	
	/**
	* Creates an instance of the ElasticForce class.
	* 
	* @param	anchorX		The x position that the particle is pulled towards.
	* @param	anchorY		The y position that the particle is pulled towards.
	* @param	tautness	The stiffness of the force of elasticity; a value between 0 and 1.
	* @param	life		The lifespan of the force in frames; this defaults to infinity if the parameter is omitted.
	* 
	* @usage
	* <pre><code>
	* var eForce:ElasticForce = new ElasticForce(0, 0, .002);
	* </code></pre>
	*/
	function ElasticForce (anchorX:Number, anchorY:Number, tautness:Number, life:Number) {
		super (0, 0, life);
		this.$anchor = new Vector (anchorX, anchorY);
		this.$tautness = tautness;
	}
	
	
	/*
	* *********************************************************
	* PRIVATE METHODS
	* *********************************************************
	* 
	*/
	
	private function update ():Void {
		with (this) {
			$value = $parentPos.minusNew ($anchor);
			$value.scale (-$tautness);
		}
	}
	
	
	/*
	* *********************************************************
	* PUBLIC METHODS
	* *********************************************************
	* 
	*/
	
	/**
	* Gets the anchor of an ElasticForce instance.
	* 
	* @usage
	* <pre><code>
	* trace (eForce.getAnchor());
	* </code></pre>
	*/
	public function getAnchor ():Vector {
		return this.anchor;
	}
	
	/**
	* Sets the anchor of an ElasticForce instance.
	* 
	* @param	x		The anchor's x position of the ElasticForce.
	* @param	y		The anchor's y position of the ElasticForce.
	* 
	* @usage
	* <pre><code>
	* var eForce:ElasticForce = new ElasticForce(0, 0, .002);
	* eForce.setAnchor(100, 250);
	* </code></pre>
	*/
	public function setAnchor (x:Number, y:Number):Void {
		this.$anchor.reset (x, y);
	}
	
	
	/*
	* *********************************************************
	* GETTERS/SETTERS
	* *********************************************************
	* 
	*/
	
	/**
	* The anchor property of the ElasticForce.
	* 
	* @usage
	* <pre><code>
	* trace (eForce.anchor);
	* </code></pre>
	*/
	public function get anchor ():Vector {
		return this.$anchor;
	}
	
	/**
	* The tautness property of the ElasticForce.
	* 
	* @usage
	* <pre><code>
	* trace (eForce.tautness);
	* </code></pre>
	*/
	public function get tautness ():Number {
		return this.$tautness;
	}
	public function set tautness (t:Number):Void {
		 this.$tautness = t;
	}
	
}
