﻿import com.robertpenner.physics.PhysicsParticle;
import com.robertpenner.physics.Force;
import com.robertpenner.physics.forces.ElasticForce;
import com.robertpenner.utils.MathUtil;

/**
* The AuroraParticle class controls a MovieClip, 
* turning it into a particle simulating the Aurora Borealis.
* 
* @author Robert Penner (AS 1.0)
* © 2002 Robert Penner
* http://www.robertpenner.com
* 
* @author Mark Walters (AS 2.0)
* © 2006 DigitalFlipbook
* http://www.digitalflipbook.com
* 
* @version	1.0
* 
* @since	ActionScript 2.0; Flash Player 6
*/
class com.robertpenner.profmx.auroraBorealis.AuroraParticle extends MovieClip {
	
	/*
	* CLASS PROPERTIES
	*/
	private var $particle:PhysicsParticle;
	private var $eForce:ElasticForce;
	private var $t:Number = 0;
	private var $brownInterval:Number = 0;
	public var setTint:Function;
	
	
	/*
	* *********************************************************
	* CONSTRUCTOR
	* *********************************************************
	*
	*/
	
	function AuroraParticle () {
		this.init();
	}
	
	
	/*
	* *********************************************************
	* PRIVATE METHODS
	* *********************************************************
	* 
	*/
	
	private function init ():Void {
		this.$particle = new PhysicsParticle (this, 0, 0, "_x", "_yscale");
		this.$particle.setFriction (.05, .05);
		this.$eForce = new ElasticForce (0, 0, .002);
		this.$particle.addForce ("elastic", this.$eForce);
		com.robertpenner.display.ColorClip.mixin(this);
		this.$t = 0;
		this.onEnterFrame = this.live;
	}

	private function live ():Void {
		this.$eForce.setAnchor (_parent._xmouse, _parent._ymouse);
		if (++this.$t % this.brownInterval == 0) { 
			var brownX:Number = MathUtil.randRangeFloat (-.2, .2);
			var brownYScale:Number = MathUtil.randRangeFloat (-.8, .8);
			var brownForce:Force = new Force (brownX, brownYScale, 5);
			this.$particle.addForce ("brown", brownForce);
		}
		var velX:Number = this.$particle.velocity.x; 
		this._xscale = velX * 150;
		this._alpha = this._width * 8;

		var r:Number = 10 * velX * velX;
		var g:Number = this._x * 1.5 + 120;
		var b:Number = this._height * this._height / 300;
		this.setTint (r, g, b, 100);
	}
	
	
	/*
	* *********************************************************
	* GETTERS/SETTERS
	* *********************************************************
	* 
	*/
	
	/**
	* The particle property of the AuroraParticle.
	* 
	* @usage
	* <pre><code>
	* trace (auroraParticle.particle);
	* </code></pre>
	*/
	public function get particle ():PhysicsParticle {
		return this.$particle;
	}
	
	/**
	* The eForce property of the AuroraParticle.
	* 
	* @usage
	* <pre><code>
	* trace (auroraParticle.eForce);
	* </code></pre>
	*/
	public function get eForce ():ElasticForce {
		return this.$eForce;
	}
	
	/**
	* The brownInterval property of the AuroraParticle.
	* 
	* @usage
	* <pre><code>
	* trace (auroraParticle.brownInterval);
	* </code></pre>
	*/
	public function get brownInterval ():Number {
		return this.$brownInterval;
	}
	public function set brownInterval (bi:Number):Void {
		 this.$brownInterval = bi;
	}
	
}
